@@ -360,3 +360,7 @@ char *format_str(const char *fmt, ...) {
 	va_end(args);
 	return str;
 }
+
+bool has_prefix(const char *str, const char *prefix) {
+	return strncmp(str, prefix, strlen(prefix)) == 0;
+}
