@@ -32,6 +32,7 @@ struct sway_tablet_pad {
 	struct wl_list link;
 	struct sway_seat_device *seat_device;
 	struct sway_tablet *tablet;
+	struct wlr_tablet_pad *wlr;
 	struct wlr_tablet_v2_tablet_pad *tablet_v2_pad;
 
 	struct wl_listener attach;
@@ -62,7 +63,7 @@ void sway_configure_tablet_pad(struct sway_tablet_pad *tablet_pad);
 
 void sway_tablet_pad_destroy(struct sway_tablet_pad *tablet_pad);
 
-void sway_tablet_pad_notify_enter(struct sway_tablet_pad *tablet_pad,
+void sway_tablet_pad_set_focus(struct sway_tablet_pad *tablet_pad,
 		struct wlr_surface *surface);
 
 #endif
