@@ -1,6 +1,7 @@
 #ifndef _SWAY_IPC_JSON_H
 #define _SWAY_IPC_JSON_H
 #include <json.h>
+#include "sway/output.h"
 #include "sway/tree/container.h"
 #include "sway/input/input-manager.h"
 
@@ -9,6 +10,7 @@ json_object *ipc_json_get_version(void);
 json_object *ipc_json_get_binding_mode(void);
 
 json_object *ipc_json_describe_disabled_output(struct sway_output *o);
+json_object *ipc_json_describe_non_desktop_output(struct sway_output_non_desktop *o);
 json_object *ipc_json_describe_node(struct sway_node *node);
 json_object *ipc_json_describe_node_recursive(struct sway_node *node);
 json_object *ipc_json_describe_input(struct sway_input_device *device);
