@@ -57,7 +57,6 @@ struct sway_output {
 
 	struct wl_listener layout_destroy;
 	struct wl_listener destroy;
-	struct wl_listener commit;
 	struct wl_listener present;
 	struct wl_listener frame;
 	struct wl_listener request_state;
@@ -72,7 +71,6 @@ struct sway_output {
 	uint32_t refresh_nsec;
 	int max_render_time; // In milliseconds
 	struct wl_event_source *repaint_timer;
-	bool gamma_lut_changed;
 	bool allow_tearing;
 };
 
@@ -93,6 +91,9 @@ struct sway_output *output_from_wlr_output(struct wlr_output *output);
 struct sway_output *output_get_in_direction(struct sway_output *reference,
 		enum wlr_direction direction);
 
+void output_configure_scene(struct sway_output *output,
+	struct wlr_scene_node *node, float opacity);
+
 void output_add_workspace(struct sway_output *output,
 		struct sway_workspace *workspace);
 
@@ -136,9 +137,6 @@ enum sway_container_layout output_get_default_layout(
 
 enum wlr_direction opposite_direction(enum wlr_direction d);
 
-
-void handle_gamma_control_set_gamma(struct wl_listener *listener, void *data);
-
 void handle_output_manager_apply(struct wl_listener *listener, void *data);
 
 void handle_output_manager_test(struct wl_listener *listener, void *data);
