@@ -1,10 +1,14 @@
 #ifndef _SWAYNAG_TYPES_H
 #define _SWAYNAG_TYPES_H
 
+#include <stdint.h>
+#include <pango/pangocairo.h>
+#include "list.h"
+
 struct swaynag_type {
 	char *name;
 
-	char *font;
+	PangoFontDescription *font_description;
 	char *output;
 	uint32_t anchors;
 	int32_t layer; // enum zwlr_layer_shell_v1_layer or -1 if unset
