@@ -25,16 +25,6 @@ struct cmd_results *cmd_exec_validate(int argc, char **argv) {
 	return error;
 }
 
-static void export_xdga_token(struct launcher_ctx *ctx) {
-	const char *token = launcher_ctx_get_token_name(ctx);
-	setenv("XDG_ACTIVATION_TOKEN", token, 1);
-}
-
-static void export_startup_id(struct launcher_ctx *ctx) {
-	const char *token = launcher_ctx_get_token_name(ctx);
-	setenv("DESKTOP_STARTUP_ID", token, 1);
-}
-
 struct cmd_results *cmd_exec_process(int argc, char **argv) {
 	struct cmd_results *error = NULL;
 	char *cmd = NULL;
@@ -56,67 +46,37 @@ struct cmd_results *cmd_exec_process(int argc, char **argv) {
 
 	sway_log(SWAY_DEBUG, "Executing %s", cmd);
 
-	int fd[2];
-	if (pipe(fd) != 0) {
-		sway_log(SWAY_ERROR, "Unable to create pipe for fork");
-	}
-
-	pid_t pid, child;
 	struct launcher_ctx *ctx = launcher_ctx_create_internal();
+
 	// Fork process
-	if ((pid = fork()) == 0) {
-		// Fork child process again
-		restore_nofile_limit();
+	pid_t child = fork();
+	if (child == 0) {
 		setsid();
-		sigset_t set;
-		sigemptyset(&set);
-		sigprocmask(SIG_SETMASK, &set, NULL);
-		signal(SIGPIPE, SIG_DFL);
-		close(fd[0]);
-		if ((child = fork()) == 0) {
-			close(fd[1]);
-			if (ctx) {
-				export_xdga_token(ctx);
+
+		if (ctx) {
+			const char *token = launcher_ctx_get_token_name(ctx);
+			setenv("XDG_ACTIVATION_TOKEN", token, 1);
+			if (!no_startup_id) {
+				setenv("DESKTOP_STARTUP_ID", token, 1);
 			}
-			if (ctx && !no_startup_id) {
-				export_startup_id(ctx);
-			}
-			execlp("sh", "sh", "-c", cmd, (void *)NULL);
-			sway_log_errno(SWAY_ERROR, "execlp failed");
-			_exit(1);
 		}
-		ssize_t s = 0;
-		while ((size_t)s < sizeof(pid_t)) {
-			s += write(fd[1], ((uint8_t *)&child) + s, sizeof(pid_t) - s);
-		}
-		close(fd[1]);
+
+		execlp("sh", "sh", "-c", cmd, (void*)NULL);
+		sway_log_errno(SWAY_ERROR, "execve failed");
 		_exit(0); // Close child process
-	} else if (pid < 0) {
+	} else if (child < 0) {
+		launcher_ctx_destroy(ctx);
 		free(cmd);
-		close(fd[0]);
-		close(fd[1]);
 		return cmd_results_new(CMD_FAILURE, "fork() failed");
 	}
-	free(cmd);
-	close(fd[1]); // close write
-	ssize_t s = 0;
-	while ((size_t)s < sizeof(pid_t)) {
-		s += read(fd[0], ((uint8_t *)&child) + s, sizeof(pid_t) - s);
-	}
-	close(fd[0]);
-	// cleanup child process
-	waitpid(pid, NULL, 0);
-	if (child > 0) {
-		sway_log(SWAY_DEBUG, "Child process created with pid %d", child);
-		if (ctx != NULL) {
-			sway_log(SWAY_DEBUG, "Recording workspace for process %d", child);
-			ctx->pid = child;
-		}
-	} else {
-		launcher_ctx_destroy(ctx);
-		return cmd_results_new(CMD_FAILURE, "Second fork() failed");
+
+	sway_log(SWAY_DEBUG, "Child process created with pid %d", child);
+	if (ctx != NULL) {
+		sway_log(SWAY_DEBUG, "Recording workspace for process %d", child);
+		ctx->pid = child;
 	}
 
+	free(cmd);
 	return cmd_results_new(CMD_SUCCESS, NULL);
 }
 
