@@ -1,9 +1,9 @@
-#define _POSIX_C_SOURCE 200809L
 #include <assert.h>
 #include <wlr/interfaces/wlr_keyboard.h>
 #include "sway/config.h"
 #include "sway/commands.h"
 #include "sway/input/input-manager.h"
+#include "sway/server.h"
 #include "log.h"
 
 struct xkb_switch_layout_action {
@@ -95,10 +95,18 @@ struct cmd_results *input_cmd_xkb_switch_layout(int argc, char **argv) {
 			continue;
 		}
 
+		struct wlr_keyboard *keyboard =
+			wlr_keyboard_from_input_device(dev->wlr_device);
+		if (keyboard->keymap == NULL && dev->is_virtual) {
+			// The `sway_keyboard_set_layout` function is by default skipped
+			// when configuring virtual keyboards.
+			continue;
+		}
+
 		struct xkb_switch_layout_action *action =
 			&actions[actions_len++];
+		action->keyboard = keyboard;
 
-		action->keyboard = wlr_keyboard_from_input_device(dev->wlr_device);
 		if (relative) {
 			action->layout = get_layout_relative(action->keyboard, relative);
 		} else {
