@@ -1,4 +1,3 @@
-#define _POSIX_C_SOURCE 200809L
 #include <strings.h>
 #include "config.h"
 #include "log.h"
@@ -19,7 +18,7 @@ static bool test_con_id(struct sway_container *container, void *data) {
 	return container->node.id == *con_id;
 }
 
-#if HAVE_XWAYLAND
+#if WLR_HAS_XWAYLAND
 static bool test_id(struct sway_container *container, void *data) {
 	xcb_window_t *wid = data;
 	return (container->view && container->view->type == SWAY_VIEW_XWAYLAND
@@ -54,7 +53,7 @@ struct cmd_results *cmd_swap(int argc, char **argv) {
 
 	char *value = join_args(argv + 3, argc - 3);
 	if (strcasecmp(argv[2], "id") == 0) {
-#if HAVE_XWAYLAND
+#if WLR_HAS_XWAYLAND
 		xcb_window_t id = strtol(value, NULL, 0);
 		other = root_find_container(test_id, &id);
 #endif
