@@ -10,7 +10,7 @@ struct cmd_results *cmd_xwayland(int argc, char **argv) {
 		return error;
 	}
 
-#ifdef HAVE_XWAYLAND
+#ifdef WLR_HAS_XWAYLAND
 	enum xwayland_mode xwayland;
 	if (strcmp(argv[0], "force") == 0) {
 		xwayland = XWAYLAND_MODE_IMMEDIATE;
@@ -20,6 +20,8 @@ struct cmd_results *cmd_xwayland(int argc, char **argv) {
 		xwayland = XWAYLAND_MODE_DISABLED;
 	}
 
+	// config->xwayland is reset to the previous value on reload in
+	// load_main_config()
 	if (config->reloading && config->xwayland != xwayland) {
 		return cmd_results_new(CMD_FAILURE,
 				"xwayland can only be enabled/disabled at launch");
