@@ -6,6 +6,7 @@
 #include <sys/wait.h>
 #include <unistd.h>
 #include <wlr/config.h>
+#include <wlr/render/allocator.h>
 #include <wlr/types/wlr_cursor.h>
 #include <wlr/types/wlr_output_layout.h>
 #include <wlr/types/wlr_output.h>
@@ -66,7 +67,7 @@ struct output_config *new_output_config(const char *name) {
 	oc->refresh_rate = -1;
 	oc->custom_mode = -1;
 	oc->drm_mode.type = -1;
-	oc->x = oc->y = -1;
+	oc->x = oc->y = INT_MAX;
 	oc->scale = -1;
 	oc->scale_filter = SCALE_FILTER_DEFAULT;
 	oc->transform = -1;
@@ -92,11 +93,11 @@ static void supersede_output_config(struct output_config *dst, struct output_con
 	if (src->height != -1) {
 		dst->height = -1;
 	}
-	if (src->x != -1) {
-		dst->x = -1;
+	if (src->x != INT_MAX) {
+		dst->x = INT_MAX;
 	}
-	if (src->y != -1) {
-		dst->y = -1;
+	if (src->y != INT_MAX) {
+		dst->y = INT_MAX;
 	}
 	if (src->scale != -1) {
 		dst->scale = -1;
@@ -128,6 +129,13 @@ static void supersede_output_config(struct output_config *dst, struct output_con
 	if (src->render_bit_depth != RENDER_BIT_DEPTH_DEFAULT) {
 		dst->render_bit_depth = RENDER_BIT_DEPTH_DEFAULT;
 	}
+	if (src->set_color_transform) {
+		if (dst->color_transform) {
+			wlr_color_transform_unref(dst->color_transform);
+			dst->color_transform = NULL;
+		}
+		dst->set_color_transform = false;
+	}
 	if (src->background) {
 		free(dst->background);
 		dst->background = NULL;
@@ -143,6 +151,9 @@ static void supersede_output_config(struct output_config *dst, struct output_con
 	if (src->power != -1) {
 		dst->power = -1;
 	}
+	if (src->allow_tearing != -1) {
+		dst->allow_tearing = -1;
+	}
 }
 
 // merge_output_config sets all fields in dst that were set in src
@@ -156,10 +167,10 @@ static void merge_output_config(struct output_config *dst, struct output_config
 	if (src->height != -1) {
 		dst->height = src->height;
 	}
-	if (src->x != -1) {
+	if (src->x != INT_MAX) {
 		dst->x = src->x;
 	}
-	if (src->y != -1) {
+	if (src->y != INT_MAX) {
 		dst->y = src->y;
 	}
 	if (src->scale != -1) {
@@ -526,21 +537,13 @@ static bool finalize_output_config(struct output_config *oc, struct sway_output
 	}
 
 	// Find position for it
-	if (oc && (oc->x != -1 || oc->y != -1)) {
+	if (oc && oc->x != INT_MAX && oc->y != INT_MAX) {
 		sway_log(SWAY_DEBUG, "Set %s position to %d, %d", oc->name, oc->x, oc->y);
 		wlr_output_layout_add(root->output_layout, wlr_output, oc->x, oc->y);
 	} else {
 		wlr_output_layout_add_auto(root->output_layout, wlr_output);
 	}
 
-	// Update output->{lx, ly, width, height}
-	struct wlr_box output_box;
-	wlr_output_layout_get_box(root->output_layout, wlr_output, &output_box);
-	output->lx = output_box.x;
-	output->ly = output_box.y;
-	output->width = output_box.width;
-	output->height = output_box.height;
-
 	if (!output->enabled) {
 		output_enable(output);
 	}
@@ -562,6 +565,15 @@ static bool finalize_output_config(struct output_config *oc, struct sway_output
 	return true;
 }
 
+static void output_update_position(struct sway_output *output) {
+	struct wlr_box output_box;
+	wlr_output_layout_get_box(root->output_layout, output->wlr_output, &output_box);
+	output->lx = output_box.x;
+	output->ly = output_box.y;
+	output->width = output_box.width;
+	output->height = output_box.height;
+}
+
 // find_output_config_from_list returns a merged output_config containing all
 // stored configuration that applies to the specified output.
 static struct output_config *find_output_config_from_list(
@@ -772,7 +784,7 @@ static bool search_render_format(struct search_context *ctx, size_t output_idx)
 	}
 
 	const struct wlr_drm_format_set *primary_formats =
-		wlr_output_get_primary_formats(wlr_output, WLR_BUFFER_CAP_DMABUF);
+		wlr_output_get_primary_formats(wlr_output, server.allocator->buffer_caps);
 	enum render_bit_depth needed_bits = RENDER_BIT_DEPTH_8;
 	if (cfg->config && cfg->config->render_bit_depth != RENDER_BIT_DEPTH_DEFAULT) {
 		needed_bits = cfg->config->render_bit_depth;
@@ -782,7 +794,8 @@ static bool search_render_format(struct search_context *ctx, size_t output_idx)
 		if (needed_bits < format_bits) {
 			continue;
 		}
-		if (!wlr_drm_format_set_get(primary_formats, fmts[idx])) {
+		// If primary_formats is NULL, all formats are supported
+		if (primary_formats && !wlr_drm_format_set_get(primary_formats, fmts[idx])) {
 			// This is not a supported format for this output
 			continue;
 		}
@@ -933,6 +946,13 @@ static bool apply_resolved_output_configs(struct matched_output_config *configs,
 		sway_log(SWAY_DEBUG, "Finalizing config for %s",
 			cfg->output->wlr_output->name);
 		finalize_output_config(cfg->config, cfg->output);
+	}
+
+	// Output layout being applied in finalize_output_config can shift outputs
+	// around, so we do a second pass to update positions and arrange.
+	for (size_t idx = 0; idx < configs_len; idx++) {
+		struct matched_output_config *cfg = &configs[idx];
+		output_update_position(cfg->output);
 		arrange_layers(cfg->output);
 	}
 
@@ -1008,6 +1028,7 @@ void free_output_config(struct output_config *oc) {
 	free(oc->name);
 	free(oc->background);
 	free(oc->background_option);
+	free(oc->background_fallback);
 	wlr_color_transform_unref(oc->color_transform);
 	free(oc);
 }
@@ -1049,42 +1070,27 @@ static bool _spawn_swaybg(char **command) {
 		sway_log_errno(SWAY_ERROR, "fork failed");
 		return false;
 	} else if (pid == 0) {
-		restore_nofile_limit();
-
-		pid = fork();
-		if (pid < 0) {
-			sway_log_errno(SWAY_ERROR, "fork failed");
-			_exit(EXIT_FAILURE);
-		} else if (pid == 0) {
-			if (!sway_set_cloexec(sockets[1], false)) {
-				_exit(EXIT_FAILURE);
-			}
-
-			char wayland_socket_str[16];
-			snprintf(wayland_socket_str, sizeof(wayland_socket_str),
-				"%d", sockets[1]);
-			setenv("WAYLAND_SOCKET", wayland_socket_str, true);
-
-			execvp(command[0], command);
-			sway_log_errno(SWAY_ERROR, "failed to execute '%s' "
-				"(background configuration probably not applied)",
-				command[0]);
+		if (!sway_set_cloexec(sockets[1], false)) {
 			_exit(EXIT_FAILURE);
 		}
-		_exit(EXIT_SUCCESS);
+
+		char wayland_socket_str[16];
+		snprintf(wayland_socket_str, sizeof(wayland_socket_str),
+			"%d", sockets[1]);
+		setenv("WAYLAND_SOCKET", wayland_socket_str, true);
+
+		execvp(command[0], command);
+		sway_log_errno(SWAY_ERROR, "failed to execute '%s' "
+			"(background configuration probably not applied)",
+			command[0]);
+		_exit(EXIT_FAILURE);
 	}
 
 	if (close(sockets[1]) != 0) {
 		sway_log_errno(SWAY_ERROR, "close failed");
 		return false;
 	}
-	int fork_status = 0;
-	if (waitpid(pid, &fork_status, 0) < 0) {
-		sway_log_errno(SWAY_ERROR, "waitpid failed");
-		return false;
-	}
-
-	return WIFEXITED(fork_status) && WEXITSTATUS(fork_status) == EXIT_SUCCESS;
+	return true;
 }
 
 bool spawn_swaybg(void) {
