@@ -1,5 +1,6 @@
 #include <stdlib.h>
 #include <wlr/types/wlr_idle_notify_v1.h>
+#include <wlr/types/wlr_session_lock_v1.h>
 #include "log.h"
 #include "sway/desktop/idle_inhibit_v1.h"
 #include "sway/input/seat.h"
@@ -44,6 +45,14 @@ void handle_idle_inhibitor_v1(struct wl_listener *listener, void *data) {
 	sway_idle_inhibit_v1_check_active();
 }
 
+void handle_manager_destroy(struct wl_listener *listener, void *data) {
+	struct sway_idle_inhibit_manager_v1 *manager =
+		wl_container_of(listener, manager, manager_destroy);
+
+	wl_list_remove(&manager->manager_destroy.link);
+	wl_list_remove(&manager->new_idle_inhibitor_v1.link);
+}
+
 void sway_idle_inhibit_v1_user_inhibitor_register(struct sway_view *view,
 		enum sway_idle_inhibit_mode mode) {
 	struct sway_idle_inhibit_manager_v1 *manager = &server.idle_inhibit_manager_v1;
@@ -103,11 +112,34 @@ void sway_idle_inhibit_v1_user_inhibitor_destroy(
 }
 
 bool sway_idle_inhibit_v1_is_active(struct sway_idle_inhibitor_v1 *inhibitor) {
+	if (server.session_lock.lock) {
+		// A session lock is active. In this case, only application inhibitors
+		// on the session lock surface can have any effect.
+		if (inhibitor->mode != INHIBIT_IDLE_APPLICATION) {
+			return false;
+		}
+		struct wlr_surface *wlr_surface = inhibitor->wlr_inhibitor->surface;
+		if (!wlr_session_lock_surface_v1_try_from_wlr_surface(wlr_surface)) {
+			return false;
+		}
+		return wlr_surface->mapped;
+	}
+
 	switch (inhibitor->mode) {
 	case INHIBIT_IDLE_APPLICATION:;
-		// If there is no view associated with the inhibitor, assume visible
-		struct sway_view *view = view_from_wlr_surface(inhibitor->wlr_inhibitor->surface);
-		return !view || !view->container || view_is_visible(view);
+		struct wlr_surface *wlr_surface = inhibitor->wlr_inhibitor->surface;
+		struct wlr_layer_surface_v1 *layer_surface =
+				wlr_layer_surface_v1_try_from_wlr_surface(wlr_surface);
+		if (layer_surface) {
+			// Layer surfaces can be occluded but are always on screen after
+			// they have been mapped.
+			return layer_surface->output && layer_surface->output->enabled &&
+					wlr_surface->mapped;
+		}
+
+		// If there is no view associated with the inhibitor, assume invisible
+		struct sway_view *view = view_from_wlr_surface(wlr_surface);
+		return view && view->container && view_is_visible(view);
 	case INHIBIT_IDLE_FOCUS:;
 		struct sway_seat *seat = NULL;
 		wl_list_for_each(seat, &server.input->seats, link) {
@@ -153,6 +185,9 @@ bool sway_idle_inhibit_manager_v1_init(void) {
 	wl_signal_add(&manager->wlr_manager->events.new_inhibitor,
 		&manager->new_idle_inhibitor_v1);
 	manager->new_idle_inhibitor_v1.notify = handle_idle_inhibitor_v1;
+	wl_signal_add(&manager->wlr_manager->events.destroy,
+		&manager->manager_destroy);
+	manager->manager_destroy.notify = handle_manager_destroy;
 	wl_list_init(&manager->inhibitors);
 
 	return true;
