@@ -221,7 +221,7 @@ static void handle_output_destroy(struct wl_listener *listener, void *data) {
 		wl_container_of(listener, layer, output_destroy);
 
 	layer->output = NULL;
-	wlr_scene_node_destroy(&layer->scene->tree->node);
+	wlr_layer_surface_v1_destroy(layer->layer_surface);
 }
 
 static void handle_node_destroy(struct wl_listener *listener, void *data) {
@@ -269,12 +269,8 @@ static void handle_surface_commit(struct wl_listener *listener, void *data) {
 		wl_container_of(listener, surface, surface_commit);
 
 	struct wlr_layer_surface_v1 *layer_surface = surface->layer_surface;
-	if (!layer_surface->initialized) {
-		return;
-	}
-
 	uint32_t committed = layer_surface->current.committed;
-	if (committed & WLR_LAYER_SURFACE_V1_STATE_LAYER) {
+	if (layer_surface->initialized && committed & WLR_LAYER_SURFACE_V1_STATE_LAYER) {
 		enum zwlr_layer_shell_v1_layer layer_type = layer_surface->current.layer;
 		struct wlr_scene_tree *output_layer = sway_layer_get_scene(
 			surface->output, layer_type);
