@@ -1,6 +1,4 @@
-#define _POSIX_C_SOURCE 200809L
 #include <wlr/types/wlr_cursor.h>
-#include "sway/desktop.h"
 #include "sway/desktop/transaction.h"
 #include "sway/input/cursor.h"
 #include "sway/input/seat.h"
@@ -23,7 +21,7 @@ static void finalize_move(struct sway_seat *seat) {
 
 static void handle_button(struct sway_seat *seat, uint32_t time_msec,
 		struct wlr_input_device *device, uint32_t button,
-		enum wlr_button_state state) {
+		enum wl_pointer_button_state state) {
 	if (seat->cursor->pressed_button_count == 0) {
 		finalize_move(seat);
 	}
@@ -39,9 +37,7 @@ static void handle_tablet_tool_tip(struct sway_seat *seat,
 static void handle_pointer_motion(struct sway_seat *seat, uint32_t time_msec) {
 	struct seatop_move_floating_event *e = seat->seatop_data;
 	struct wlr_cursor *cursor = seat->cursor->cursor;
-	desktop_damage_whole_container(e->con);
 	container_floating_move_to(e->con, cursor->x - e->dx, cursor->y - e->dy);
-	desktop_damage_whole_container(e->con);
 	transaction_commit_dirty();
 }
 
