@@ -1,4 +1,3 @@
-#define _POSIX_C_SOURCE 200809L
 #include "sway/output.h"
 #include "sway/server.h"
 #include "sway/tree/container.h"
@@ -159,3 +158,32 @@ bool node_has_ancestor(struct sway_node *node, struct sway_node *ancestor) {
 	}
 	return false;
 }
+
+void scene_node_disown_children(struct wlr_scene_tree *tree) {
+	// this function can be called as part of destruction code that will be invoked
+	// upon an allocation failure. Let's not crash on NULL due to an allocation error.
+	if (!tree) {
+		return;
+	}
+
+	struct wlr_scene_node *child, *tmp_child;
+	wl_list_for_each_safe(child, tmp_child, &tree->children, link) {
+		wlr_scene_node_reparent(child, root->staging);
+	}
+}
+
+struct wlr_scene_tree *alloc_scene_tree(struct wlr_scene_tree *parent,
+		bool *failed) {
+	// fallthrough
+	if (*failed) {
+		return NULL;
+	}
+
+	struct wlr_scene_tree *tree = wlr_scene_tree_create(parent);
+	if (!tree) {
+		sway_log(SWAY_ERROR, "Failed to allocate a scene node");
+		*failed = true;
+	}
+
+	return tree;
+}
